//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// September 2000
//

// Given a list of CIFs and a directory of constituents, remove all
// the constituents that not in the CIFs.

#include <iostream>
#include <Dal.h>
#include <SasDalUtils.h>
#include <Directory.h>
#include <algorithm>
#include <unistd.h>
#include <set>

int main(int argc, char *argv[])
{

  if(argc < 3)
    exit(1);

  using namespace SasDalUtils;
  set<string> ccf;

  for(int i = 1; i < argc - 1; i++){ 
    cout << "CIF = " << argv[i] << endl;
    DataSet *set = dataSetServer->open(argv[i], Dal::Read);
    Table *tab = set->table("CALINDEX");
    ColumnData *col = tab->column("FNAME")->data();
    for(unsigned k = 0; k < tab->rows(); k++)
      ccf.insert(getStringColumnRow(col,k));
    delete col;
  }

  Directory dir(argv[argc - 1]);
  dir.filter("*.CCF");
  for(Directory::const_iterator j = dir.begin(); j != dir.end(); j++){
    const DirEntry &e = **j;
    if(ccf.find(e.basename()) == ccf.end()){    
      cout << "Removed: " << e.name() << endl;
      unlink(e.name().c_str());
    } //else {
      //      cout << " Kept: " << e.name() << endl;
      // }
  }

  dir.filter("*.CCF");
  for(Directory::const_iterator j = dir.begin(); j != dir.end(); j++){
    const DirEntry &e = **j;
    if(ccf.find(e.basename()) == ccf.end()){    
      cerr << e.basename() << " missing" << endl;
    }
  }
}
